/* $Workfile: OtxDmpD.h $   $Revision: 3 $    $Modtime: 1/16/08 3:44p $  */
#ifndef OTX_DMP_DEF_H
#define OTX_DMP_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxDmpD

  Copyright (C) 2007 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxDmpD | Constants, Macros, and Types for the DMP Device Management Functions

  @contents2
  OtxDmpD.h |

  @index enum struct type | OtxDmpD

  @contents2
  OTX DMP Device Management Macros, Constants, and Types |

  @head3 OtxDmpXXX Macro, Constant, and Type Reference |

  @index enum struct type | OtxDmpD

*******************************************************************************/

#include "OtxType.h"    // OTX specific type definitions

#include "OtxErr.h"

#ifdef __cplusplus
extern "C" {
#endif


/*******************************************************************************
  @enum Standard Program Modules (SPM)

  @comm DMP program modules are loaded in the DMPs by calling <f OtxDmpRunSpm>. 


*******************************************************************************/
enum OtxDmpSpmE {
  OTX_DMP_SPM_OTXSPM2,          // @emem DMP Program OtxSpm2.out
};

typedef enum OtxDmpSpmE OtxDmpSpmE;


/******************************************************************************
  @enum 
    DMP Device Attributes
******************************************************************************/
enum OtxDmpDeviceAttributesE {
  OTX_ATTR_DMP_NOTIFICATION_EVENT_BUF_CURRENT_USAGE            = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read-only. Current number of words in use of the 
                                                                                    // HPI Notification Event Buffer
  OTX_ATTR_DMP_NOTIFICATION_EVENT_BUF_MAX_USAGE                = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_UINT32) Read-only. Maximum number of words in use of the 
                                                                                    // HPI Notification Event Buffer (since the application started)
  OTX_ATTR_DMP_NOTIFICATION_EVENT_BUF_LOST_EVENTS              = OTX_ATTR_END + 2,  // @emem (OTX_ATTRIB_UINT32) Read-only. Number of the lost events (due to a 
                                                                                    // full HPI Notification Event Buffer)
  OTX_ATTR_DMP_NOTIFICATION_EVENT_EXT_QUEUE_CURRENT_USAGE      = OTX_ATTR_END + 3,  // @emem (OTX_ATTRIB_UINT32) Read-only. Current number of Notification Event packets
                                                                                    // in the extended event queue (located outside of the HPI Notification Buffer)  
  OTX_ATTR_DMP_NOTIFICATION_EVENT_EXT_QUEUE_PEAK_USAGE         = OTX_ATTR_END + 4,  // @emem (OTX_ATTRIB_UINT32) Read-only. Current number of Notification Event packets
                                                                                    // in the extended event queue (located outside of the HPI Notification Buffer)  

  OTX_ATTR_DMP_NOTIFICATION_EVENT_BUF_ADDR                     = OTX_ATTR_END + 5,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Start address of the HPI Notification 
                                                                                    // Event Buffer
  OTX_ATTR_DMP_NOTIFICATION_EVENT_BUF_SIZE                     = OTX_ATTR_END + 6,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Size (in words) of the HPI Notification Event Buffer
  OTX_ATTR_DMP_NOTIFICATION_EVENT_BUF_PROCESSING_ADDR          = OTX_ATTR_END + 7,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Address of where the host driver will 
                                                                                    // write the address of its Notification Event Buffer Read Pointer (i.e. the 
                                                                                    // address of where it will read the next Notification Event from)
  OTX_ATTR_DMP_IOCTL_CODE_ADDR                                 = OTX_ATTR_END + 8,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Start address of the DMP IO Control packet.
  OTX_ATTR_DMP_IOCTL_DATA_MAX_SIZE                             = OTX_ATTR_END + 9,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Maximum data length of the DMP IO Control 
                                                                                    // packet.
  OTX_ATTR_DMP_NOTIFICATION_EVENT_BUF_INCLUDE_HANDLE           = OTX_ATTR_END + 10,  // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the DMP code must include the 
                                                                                    // DMP Handle in the Notification Events
  OTX_ATTR_DMP_NOTIFICATION_EVENT_BUF_INCLUDE_TASKREF          = OTX_ATTR_END + 11,  // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the DMP code must include the 
                                                                                    // TaskRef in the Notification Events
  OTX_ATTR_DMP_NOTIFICATION_EVENT_BUF_INCLUDE_TIMESTAMP        = OTX_ATTR_END + 12, // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the DMP code must include the 
                                                                                    // TimeStamp in the Notification Events
  OTX_ATTR_DMP_IOCTL_INCLUDE_HANDLE                            = OTX_ATTR_END + 13, // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the host driver will include the 
                                                                                    // DMP Handle in the DMP IO Control packet
  OTX_ATTR_DMP_IOCTL_INCLUDE_TASKREF                           = OTX_ATTR_END + 14, // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the host driver will include 
                                                                                    // the TaskRef in the DMP IO Control packet
  OTX_ATTR_DMP_AUTO_DISABLE                                    = OTX_ATTR_END + 15, // @emem (OTX_ATTRIB_BOOL) Read/Write. Default OTX_TRUE. If OTX_TRUE the driver 
                                                                                    // will automatically disable the device if the Notification Event buffer encounters
                                                                                    // to many serious errors. A call to <f OtxDrvReset> will reset the error counter for
                                                                                    // serious errors.
                                                              
  OTX_ATTR_DMP_FRAME_BUFFER_COUNTER                            = OTX_ATTR_END + 16, // @emem (OTX_ATTRIB_UINT32) Read only. The Frame Buffer Counter is a 16 bit value
                                                                                    // which is incremented by the DMP code every time it receives another buffer 
                                                                                    // interrupt (highway serial port). Since each DMP is clocked from the same Frame Sync
                                                                                    // clock this counter can be used to synchronize certain events (such as a synchronized 
                                                                                    // enabling of multiple devices). The counter will wrap once it reaches 0xFFFF. The size
                                                                                    // of the frame buffer (auto buffer) is set by each DMP program, but the Frame sync pulse
                                                                                    // always occurs every 125 us.
  OTX_ATTR_DMP_FRAME_COUNTER                                   = OTX_ATTR_END + 17, // @emem (OTX_ATTRIB_UINT32) Read only. The Frame Counter is a 16 bit value
                                                                                    // which is incremented by the DMP code every time it receives another buffer 
                                                                                    // interrupt (highway serial port). It is similar to the 
                                                                                    // <e OtxDmpDeviceAttributesE.OTX_ATTR_DMP_FRAME_BUFFER_COUNTER> attribute except that this
                                                                                    // counter is incremented by the number of frames in each buffer. Therefore this attribute
                                                                                    // can be used to get an accurate count of how many frames that the DMP has received since
                                                                                    // the DMP was started. The time difference between each frame is 125us.
  OTX_ATTR_DMP_HIGHWAY_SPEED                                   = OTX_ATTR_END + 18, // @emem (OTX_ATTRIB_UINT32) Read only. DMP Highway speed in kbps. Valid values are
                                                                                    // 2048, 4096, and 8192. The highway speed determines how many timeslots that the DMP can
                                                                                    // work with. On a 2048 kpbs highway there are 32 timeslots. On a 4096 kbps highway there
                                                                                    // are 64 timeslots, and on an 8192 kpbs highway there are 128 timeslots.

  OTX_ATTR_DMP_HIGHWAY_BIT_FREQUENCY                           = OTX_ATTR_END + 19, // @emem (OTX_ATTRIB_UINT32) Read only. 
                                                                                    // <nl>If supported by the loaded DMP program,
                                                                                    // this attribute returns the bit frequency of the DMP highway in Hertz. 

  OTX_ATTR_DMP_AUTO_LOGICAL_DISCONNECT_DISABLE                 = OTX_ATTR_END + 20, // @emem (OTX_ATTRIB_BOOL) Read/Write. Default OTX_TRUE. If OTX_TRUE the driver 
                                                                                    // will automatically disable the logical device in the DMP if a <f OtxDrvDisconnectLogicalDevice>
                                                                                    // is called for that device. If OTX_FALSE, the DMP skip the disable call, and leave the
                                                                                    // logical device in the current state while disconnecting the logical device.
                                                              
  OTX_ATTR_DMP_END                                             = OTX_ATTR_END + 21
};

typedef enum OtxDmpDeviceAttributesE OtxDmpDeviceAttributesE;


/******************************************************************************
  @enum
    DMP Error Result Codes
******************************************************************************/
enum OtxDmpResultCodesE {
  OTX_DMP_RES_DATA_TOO_LARGE               = OTX_RES_END +  0 ,  // @emem Data too large for the supplied buffer. Supply a larger buffer.
  OTX_DMP_RES_INVALID_CHANNEL              = OTX_RES_END +  1 ,  // @emem Invalid channel
  OTX_DMP_RES_COMM_FAILURE                 = OTX_RES_END +  2 ,  // @emem Communication failure with the DMP
  OTX_DMP_RES_NO_KERNEL_RESPONSE           = OTX_RES_END +  3 ,  // @emem No response from DMP Kernel
  OTX_DMP_RES_NO_FREE_LOGICAL_DEVICE       = OTX_RES_END +  4 ,  // @emem No free logical device

  OTX_DMP_RES_END                          = OTX_RES_END +  1
};

typedef enum OtxDmpResultCodesE OtxDmpResultCodesE;


/******************************************************************************
  @enum
    DMP Event Codes
******************************************************************************/
enum OtxDmpEventCodesE {
  // OtxSpm1 Specific Event Codes
  OTX_DMP_EC_RX_OVERFLOW                 = 0x00, // @emem OtxSpm1 Receive overflow
  OTX_DMP_EC_INTERNAL_ERROR              = 0x01, // @emem OtxSpm1 Undefined Internal error
  OTX_DMP_EC_UNKNOWN_NOTIFY_CODE         = 0x02, // @emem OtxSpm1 Error. Unknown notify code for System Notify Event Handle.

  // Generic DMP Module Event Codes
  OTX_DMP_EC_INVALID_NOTIFY_EVENT_HANDLE = 0x03, // @emem Invalid Notify Event Handle. Could not find a matching logical device for this handle.
  OTX_DMP_EC_NOTIFY_EVENT_OVERFLOW       = 0x04, // @emem Event frequency too high. Driver cannot handle all these events. 
  OTX_DMP_EC_AUTO_DISABLED               = 0x05, // @emem Fatal error has occurred. The device is automatically disabled.
  OTX_DMP_EC_NOTIFY_EVENT_FREQ_HIGH      = 0x06, // @emem Event frequency from the DMP is seriously high. Fatal errors are imminent.
  OTX_DMP_EC_DEBUG_INFO                  = 0x07, // @emem Internal use. For driver debugging.
  OTX_DMP_EC_PACKET_QUEUED               = 0x08, // @emem For internal use only.
  OTX_DMP_EC_PACKET_FIFO_OVERRUN         = 0x09, // @emem For internal use only.
  OTX_DMP_EC_LINK_INITIALIZED            = 0x0A, // @emem The DMP to Host link is now initialized. It is now possible to make Dmp function calls.

  OTX_DMP_END_OF_EVENT_CODES          
};
typedef enum OtxDmpEventCodesE OtxDmpEventCodesE;




#ifdef __cplusplus
}  // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2007

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif    // OTX_DMP_DEF_H
